package Haemodynamics "Hemodynamic model for Human Patient Simulator"
  annotation(Diagram(coordinateSystem(extent={{-148.5,-105.0},{148.5,105.0}}, preserveAspectRatio=true, initialScale=0.1, grid={5,5})));
  package Parts "Necessary components"
    annotation(Diagram(coordinateSystem(extent={{-148.5,-105.0},{148.5,105.0}}, preserveAspectRatio=true, initialScale=0.1, grid={5,5})));
    connector BloodFlowConnector "Connector for blood flow"
      flow Real Q "blood flow in ml/sec";
      Real Pressure "Pressure in torr";
      annotation(Icon(coordinateSystem(extent={{-100.0,-100.0},{100.0,100.0}}, preserveAspectRatio=true, initialScale=0.1, grid={10,10}), graphics={Rectangle(visible=true, origin={0.0,0.3056}, fillColor={255,0,0}, fillPattern=FillPattern.Solid, extent={{-100.0,-100.3056},{100.0,100.3056}})}), Diagram(coordinateSystem(extent={{-100.0,-100.0},{100.0,100.0}}, preserveAspectRatio=true, initialScale=0.1, grid={10,10}), graphics={Text(visible=true, lineColor={0,0,255}, extent={{-160.0,50.0},{40.0,110.0}}, textString="%name", fontName="Arial"),Rectangle(visible=true, lineColor={0,0,255}, fillColor={255,0,0}, fillPattern=FillPattern.Solid, extent={{-40.0,-40.0},{40.0,40.0}})}));
    end BloodFlowConnector;

    connector BloodFlowInflow "Blood flow inflow"
      flow Real Q "blood inflow in ml/sec";
      Real Pressure "Pressure in torr";
      annotation(Icon(coordinateSystem(extent={{-100.0,-100.0},{100.0,100.0}}, preserveAspectRatio=true, initialScale=0.1, grid={10,10}), graphics={Rectangle(visible=true, origin={0.0,0.3056}, fillColor={255,0,0}, fillPattern=FillPattern.Solid, extent={{-100.0,-100.3056},{100.0,100.3056}})}), Diagram(coordinateSystem(extent={{-148.5,-105.0},{148.5,105.0}}, preserveAspectRatio=true, initialScale=0.1, grid={5,5}), graphics={Text(visible=true, lineColor={0,0,255}, extent={{-160.0,50.0},{40.0,110.0}}, textString="%name", fontName="Arial"),Rectangle(visible=true, lineColor={0,0,255}, fillColor={255,0,0}, fillPattern=FillPattern.Solid, extent={{-40.0,-40.0},{40.0,40.0}})}));
    end BloodFlowInflow;

    connector BloodFlowOutflow "Blood flow inflow"
      flow Real Q "blood flow outflow in ml/sec";
      Real Pressure "Pressure in torr";
      annotation(Icon(coordinateSystem(extent={{-100.0,-100.0},{100.0,100.0}}, preserveAspectRatio=true, initialScale=0.1, grid={10,10}), graphics={Rectangle(visible=true, origin={0.0,0.3056}, fillColor={255,255,255}, fillPattern=FillPattern.Solid, extent={{-100.0,-100.3056},{100.0,100.3056}})}), Diagram(coordinateSystem(extent={{-148.5,-105.0},{148.5,105.0}}, preserveAspectRatio=true, initialScale=0.1, grid={5,5}), graphics={Text(visible=true, lineColor={0,0,255}, extent={{-140,50},{60,110}}, textString="%name", fontName="Arial"),Rectangle(visible=true, lineColor={0,0,255}, fillColor={255,255,255}, fillPattern=FillPattern.Solid, extent={{-40,-37.5},{40,42.5}})}));
    end BloodFlowOutflow;

    partial model BloodFlowOnePort
      annotation(Diagram(coordinateSystem(extent={{-148.5,-105.0},{148.5,105.0}}, preserveAspectRatio=true, initialScale=0.1, grid={5,5})));
      Haemodynamics.Parts.BloodFlowInflow Inflow annotation(Placement(visible=true, transformation(origin={-151.1835,-0.6039}, extent={{-14.85,-10.5},{14.85,10.5}}, rotation=0), iconTransformation(origin={-100.0,-0.0}, extent={{-10.0,-10.0},{10.0,10.0}}, rotation=0)));
      Haemodynamics.Parts.BloodFlowOutflow Outflow annotation(Placement(visible=true, transformation(origin={151.1835,-0.6039}, extent={{-14.85,-10.5},{14.85,10.5}}, rotation=0), iconTransformation(origin={100.0,-0.0}, extent={{-10.0,-10.0},{10.0,10.0}}, rotation=0)));
      Real PressureDrop;
      Real BloodFlow;
    equation 
      PressureDrop=Inflow.Pressure - Outflow.Pressure;
      Inflow.Q + Outflow.Q=0;
      BloodFlow=Inflow.Q;
    end BloodFlowOnePort;

    model BloodResistor
      parameter Real BloodResistance(start=1) "resistance in torr sec/ml";
      extends Haemodynamics.Parts.BloodFlowOnePort;
    equation 
      PressureDrop=BloodFlow*BloodResistance;
      annotation(Diagram(coordinateSystem(extent={{-148.5,-105.0},{148.5,105.0}}, preserveAspectRatio=true, initialScale=0.1, grid={5,5}), graphics={Rectangle(visible=true, fillColor={255,255,255}, extent={{-60.0,-20.0},{60.0,20.0}}),Rectangle(visible=true, origin={-80.0,0.0}, fillColor={255,255,255}, extent={{-20.0,0.0},{20.0,0.0}}),Rectangle(visible=true, origin={80.0,0.0}, fillColor={255,255,255}, extent={{-20.0,0.0},{20.0,0.0}})}), Icon(coordinateSystem(extent={{-100,-100},{100,100}}, preserveAspectRatio=true, initialScale=0.1, grid={10,10}), graphics={Text(visible=true, origin={-2.6699,181}, lineColor={0,0,255}, extent={{-197.33,-81},{202.67,-41}}, fontName="Arial", textString="%name"),Text(visible=true, origin={0.8419,-77.2844}, fillPattern=FillPattern.Solid, extent={{-100.5547,-50.2773},{99.1581,-27.9318}}, fontName="Arial", textString="R=%BloodResistance", lineColor={0,0,0}),Polygon(points={{-100,100},{-100,-100},{0,0},{-100,100}}, lineColor={0,0,255}, smooth=Smooth.None, fillColor={215,215,215}, fillPattern=FillPattern.Solid),Polygon(points={{100,90},{100,-100},{0,0},{100,90}}, lineColor={0,0,255}, smooth=Smooth.None, fillColor={215,215,215}, fillPattern=FillPattern.Solid),Text(extent={{-20,80},{20,40}}, lineColor={0,0,255}, textString="R")}));
    end BloodResistor;

    model VariableBloodResistor
      extends Haemodynamics.Parts.BloodFlowOnePort;
      Modelica.Blocks.Interfaces.RealInput BloodResistance "in torr sec/ml" annotation(Placement(visible=true, transformation(origin={-10.0,67.9735}, extent={{-20.0,-20.0},{20.0,20.0}}, rotation=0), iconTransformation(origin={0.0,92.5685}, extent={{-12.5685,-12.5685},{12.5685,12.5685}}, rotation=-90)));
    equation 
      PressureDrop=BloodFlow*BloodResistance;
      annotation(Icon(coordinateSystem(extent={{-100,-100},{100,100}}, preserveAspectRatio=true, initialScale=0.1, grid={10,10}), graphics={Line(visible=true, origin={-70.0,0.0}, points={{-20.0,0.0},{20.0,0.0}}),Line(visible=true, origin={70.0,0.0}, points={{-20.0,0.0},{20.0,0.0}}),Text(visible=true, extent={{-180,-140},{190,-110}}, fontName="Arial", textString="%name", lineColor={0,0,0}),Line(visible=true, origin={0.0,50.0}, points={{0.0,30.0},{0.0,-30.0}}),Polygon(points={{-100,100},{0,0},{-100,-100},{-100,100}}, lineColor={0,0,255}, smooth=Smooth.None, fillColor={215,215,215}, fillPattern=FillPattern.Solid),Polygon(points={{100,100},{100,-100},{0,0},{100,100}}, lineColor={0,0,255}, smooth=Smooth.None, fillColor={215,215,215}, fillPattern=FillPattern.Solid),Text(extent={{0,70},{40,30}}, lineColor={0,0,255}, textString="R")}), Diagram(coordinateSystem(extent={{-148.5,-105.0},{148.5,105.0}}, preserveAspectRatio=true, initialScale=0.1, grid={5,5}), graphics={Rectangle(visible=true, fillColor={255,255,255}, extent={{-60.0,-20.0},{60.0,20.0}}),Rectangle(visible=true, origin={-80.0,0.0}, fillColor={255,255,255}, extent={{-20.0,0.0},{20.0,0.0}}),Rectangle(visible=true, origin={80.0,0.0}, fillColor={255,255,255}, extent={{-20.0,0.0},{20.0,0.0}})}));
    end VariableBloodResistor;

    model VariableBloodConductance
      extends Haemodynamics.Parts.BloodFlowOnePort;
      Modelica.Blocks.Interfaces.RealInput BloodConductance "in torr ml/sec" annotation(Placement(visible=true, transformation(origin={-10.0,67.9735}, extent={{-20.0,-20.0},{20.0,20.0}}, rotation=0), iconTransformation(origin={0.0,92.5685}, extent={{-12.5685,-12.5685},{12.5685,12.5685}}, rotation=-90)));
    equation 
      PressureDrop*BloodConductance=BloodFlow;
      annotation(Icon(coordinateSystem(extent={{-100,-100},{100,100}}, preserveAspectRatio=true, initialScale=0.1, grid={10,10}), graphics={Line(visible=true, origin={-70.0,0.0}, points={{-20.0,0.0},{20.0,0.0}}),Line(visible=true, origin={70.0,0.0}, points={{-20.0,0.0},{20.0,0.0}}),Text(visible=true, extent={{-180,-140},{190,-110}}, fontName="Arial", textString="%name", lineColor={0,0,0}),Line(visible=true, origin={0.0,50.0}, points={{0.0,30.0},{0.0,-30.0}}),Polygon(points={{-100,100},{0,0},{-100,-100},{-100,100}}, lineColor={0,0,255}, smooth=Smooth.None, fillColor={215,215,215}, fillPattern=FillPattern.Solid),Polygon(points={{100,100},{100,-100},{0,0},{100,100}}, lineColor={0,0,255}, smooth=Smooth.None, fillColor={215,215,215}, fillPattern=FillPattern.Solid),Text(extent={{0,70},{40,30}}, lineColor={0,0,255}, textString="G")}), Diagram(coordinateSystem(extent={{-148.5,-105.0},{148.5,105.0}}, preserveAspectRatio=true, initialScale=0.1, grid={5,5}), graphics={Rectangle(visible=true, fillColor={255,255,255}, extent={{-60.0,-20.0},{60.0,20.0}}),Rectangle(visible=true, origin={-80.0,0.0}, fillColor={255,255,255}, extent={{-20.0,0.0},{20.0,0.0}}),Rectangle(visible=true, origin={80.0,0.0}, fillColor={255,255,255}, extent={{-20.0,0.0},{20.0,0.0}})}));
    end VariableBloodConductance;

    model BloodElasticCompartment "Elastic compartment with unstressed volume"
      Modelica.Blocks.Interfaces.RealInput Elastance "\"in torr/ml\"" annotation(Placement(visible=true, transformation(origin={0.0957,88.3047}, extent={{-20.0,-20.0},{20.0,20.0}}, rotation=-90), iconTransformation(origin={65.0535,86.446}, extent={{-11.8243,-11.8243},{11.8243,11.8243}}, rotation=-90)));
      Modelica.Blocks.Interfaces.RealOutput Volume(start=V0) annotation(Placement(visible=true, transformation(origin={-67.3852,-78.2262}, extent={{-10.0,-10.0},{10.0,10.0}}, rotation=-90), iconTransformation(origin={-70,-67.9715}, extent={{-10.0,-10.0},{10.0,10.0}}, rotation=-90)));
      Modelica.Blocks.Interfaces.RealInput ExternalPressure "\"in torr\"" annotation(Placement(visible=true, transformation(origin={0.0957,88.3047}, extent={{-20.0,-20.0},{20.0,20.0}}, rotation=-90), iconTransformation(origin={5.0535,106.446}, extent={{-11.8243,-11.8243},{11.8243,11.8243}}, rotation=-90)));
      Modelica.Blocks.Interfaces.RealInput UnstressedVolume "in ml" annotation(Placement(visible=true, transformation(origin={0.0957,88.3047}, extent={{-20.0,-20.0},{20.0,20.0}}, rotation=-90), iconTransformation(origin={-64.947,86.446}, extent={{-11.8243,-11.8243},{11.8243,11.8243}}, rotation=-90)));
      parameter Real V0=1 "initial volume in ml";
      Real StressedVolume;
      Real TransmuralPressure;
      Modelica.Blocks.Interfaces.RealOutput Pressure "Blood pressure in torr" annotation(Placement(visible=true, transformation(origin={-67.3852,-78.2262}, extent={{-10.0,-10.0},{10.0,10.0}}, rotation=-90), iconTransformation(origin={80,-67.9715}, extent={{-10.0,-10.0},{10.0,10.0}}, rotation=-90)));
      Haemodynamics.Parts.BloodFlowConnector bloodFlow annotation(Placement(transformation(extent={{-10,-110},{10,-90}}), iconTransformation(extent={{-10,-110},{10,-90}})));
    equation 
      bloodFlow.Pressure=Pressure;
      TransmuralPressure=Pressure - ExternalPressure;
      der(Volume)=bloodFlow.Q;
      StressedVolume=Volume - UnstressedVolume;
      if StressedVolume > 0 then
        TransmuralPressure=Elastance*StressedVolume;
      else
        TransmuralPressure=0;
      end if;
      annotation(Icon(coordinateSystem(extent={{-100.0,-100.0},{100.0,100.0}}, preserveAspectRatio=true, initialScale=0.1, grid={10,10}), graphics={Ellipse(visible=true, origin={2.9379,0.0}, fillColor={215,215,215}, fillPattern=FillPattern.Solid, extent={{-102.9379,-100.0},{102.9379,100.0}}),Text(visible=true, origin={-0.3481,72.6447}, extent={{-148.0,-81.0},{152.0,-41.0}}, textString="%name", fontName="Arial"),Text(visible=true, origin={-79.158,-2.0682}, fillPattern=FillPattern.Solid, extent={{-100.5547,-50.2773},{99.1581,-27.9318}}, textString="Volume", fontName="Arial"),Text(visible=true, origin={-99.158,127.932}, fillPattern=FillPattern.Solid, extent={{-100.555,-50.2772},{99.1581,-27.9317}}, textString="UV", fontName="Arial"),Text(visible=true, origin={125.594,125.0}, fillPattern=FillPattern.Solid, extent={{-85.5943,-45.0001},{84.4058,-25.0002}}, textString="Elastance", fontName="Arial"),Text(visible=true, origin={0.842,127.932}, fillPattern=FillPattern.Solid, extent={{-100.555,-50.2772},{99.1581,-27.9317}}, textString="Pext", fontName="Arial"),Text(visible=true, origin={80.842,-2.0682}, fillPattern=FillPattern.Solid, extent={{-100.5547,-50.2773},{99.1581,-27.9318}}, textString="Pressure", fontName="Arial")}), Diagram(coordinateSystem(extent={{-148.5,-105},{148.5,105}}, preserveAspectRatio=true, initialScale=0.1, grid={5,5}), graphics));
    end BloodElasticCompartment;

    model Inductor
      extends Haemodynamics.Parts.BloodFlowOnePort;
      Modelica.Blocks.Interfaces.RealInput Inertance "in torr * sec^2/ml" annotation(Placement(visible=true, transformation(origin={-10.0,67.9735}, extent={{-20.0,-20.0},{20.0,20.0}}, rotation=0), iconTransformation(origin={0,82.5685}, extent={{-12.5685,-12.5685},{12.5685,12.5685}}, rotation=-90)));
    equation 
      PressureDrop=der(BloodFlow)*Inertance;
      annotation(Icon(coordinateSystem(extent={{-100.0,-100.0},{100.0,100.0}}, preserveAspectRatio=true, initialScale=0.1, grid={10,10}), graphics={Line(visible=true, origin={-70.0,0.0}, points={{-20.0,0.0},{20.0,0.0}}),Line(visible=true, origin={70.0,0.0}, points={{-20.0,0.0},{20.0,0.0}}),Text(visible=true, extent={{-210.0,-100.0},{210.0,-70.0}}, textString="%name", fontName="Arial"),Line(visible=true, origin={0.0,50.0}, points={{0.0,30.0},{0.0,-30.0}}),Rectangle(visible=true, lineThickness=1, extent={{-100.0,-55.0},{100.0,75.0}}),Rectangle(visible=true, lineColor={255,0,0}, fillColor={255,0,0}, pattern=LinePattern.None, fillPattern=FillPattern.Solid, lineThickness=1, extent={{-55.0,-50.0},{65.0,70.0}}),Text(visible=true, origin={8.1183,52.9448}, fillPattern=FillPattern.Solid, extent={{-78.8574,-9.8385},{78.8574,9.8385}}, textString="Inertance", fontName="Arial")}), Diagram(coordinateSystem(extent={{-148.5,-105.0},{148.5,105.0}}, preserveAspectRatio=true, initialScale=0.1, grid={5,5}), graphics={Rectangle(visible=true, fillColor={255,255,255}, extent={{-60.0,-20.0},{60.0,20.0}}),Rectangle(visible=true, origin={-80.0,0.0}, fillColor={255,255,255}, extent={{-20.0,0.0},{20.0,0.0}}),Rectangle(visible=true, origin={80.0,0.0}, fillColor={255,255,255}, extent={{-20.0,0.0},{20.0,0.0}})}));
    end Inductor;

    model Valve
      Haemodynamics.Parts.BloodFlowInflow bloodFlowInflow annotation(Placement(transformation(extent={{-106,-12},{-78,8}}), iconTransformation(extent={{-106,-10},{-78,10}})));
      Haemodynamics.Parts.BloodFlowOutflow bloodFlowOutflow annotation(Placement(transformation(extent={{70,-6},{100,16}}), iconTransformation(extent={{70,-10},{100,12}})));
      Real q;
      Real dp;
      Boolean open(start=true);
      Real passableVariable;
    equation 
      bloodFlowInflow.Q + bloodFlowOutflow.Q=0;
      q=bloodFlowInflow.Q;
      dp=bloodFlowInflow.Pressure - bloodFlowOutflow.Pressure;
      open=passableVariable > 0;
      if open then
        dp=0;
        q=passableVariable;
      else
        dp=passableVariable;
        q=0;
      end if;
      annotation(Icon(graphics={Rectangle(extent={{42,98},{66,-100}}, lineColor={0,0,255}, fillPattern=FillPattern.Solid, fillColor={255,170,170}),Polygon(points={{-70,98},{-72,-100},{36,-12},{36,12},{-70,98}}, lineColor={0,0,255}, smooth=Smooth.None, fillColor={255,170,170}, fillPattern=FillPattern.Solid),Text(extent={{-176,-116},{164,-142}}, lineColor={0,0,0}, textString="%name")}), Diagram(graphics));
    end Valve;

    connector RealDiscreteOutput= discrete output Real "'output Real' as connector" annotation(defaultComponentName="y", Icon(coordinateSystem(preserveAspectRatio=true, extent={{-100,-100},{100,100}}, grid={1,1}), graphics={Polygon(points={{-100,100},{100,0},{-100,-100},{-100,100}}, lineColor={0,0,127}, fillColor={255,255,255}, fillPattern=FillPattern.Solid)}), Diagram(coordinateSystem(preserveAspectRatio=true, extent={{-100,-100},{100,100}}, grid={1,1}), graphics={Polygon(points={{-100,50},{0,0},{-100,-50},{-100,50}}, lineColor={0,0,127}, fillColor={255,255,255}, fillPattern=FillPattern.Solid),Text(extent={{30,110},{30,60}}, lineColor={0,0,127}, textString="%name")}), Documentation(info="<html>
<p>
Connector with one output signal of type Real.
</p>
</html>"));
    model heartIntervals
      Modelica.Blocks.Interfaces.RealInput HR annotation(Placement(transformation(extent={{-134,8},{-94,48}}), iconTransformation(extent={{-134,8},{-94,48}})));
      Haemodynamics.Parts.RealDiscreteOutput Tas "duration of atrial systole" annotation(Placement(transformation(extent={{100,36},{120,56}}), iconTransformation(extent={{100,36},{120,56}})));
      Haemodynamics.Parts.RealDiscreteOutput Tav "atrioventricular delay" annotation(Placement(transformation(extent={{100,64},{120,84}}), iconTransformation(extent={{100,6},{120,26}})));
      Haemodynamics.Parts.RealDiscreteOutput Tvs "duration of ventricular systole" annotation(Placement(transformation(extent={{100,4},{120,24}}), iconTransformation(extent={{100,-32},{120,-12}})));
      Haemodynamics.Parts.RealDiscreteOutput T0 "start time of cardiac cycle in sec" annotation(Placement(transformation(extent={{100,-66},{120,-46}}), iconTransformation(extent={{100,-66},{120,-46}})));
      discrete Real HP(start=0) "heart period - duration of cardiac cycle in sec";
      Boolean b(start=false);
    equation 
      b=time - pre(T0) >= pre(HP);
      when b then
        T0=time;
        HP=60/HR;
        Tas=0.03 + 0.09*HP;
        Tav=0.01;
        Tvs=0.16 + 0.2*HP;
      end when;
      annotation(Diagram(graphics), Icon(graphics={Text(visible=true, lineColor={127,0,0}, fillColor={0,0,255}, fillPattern=FillPattern.Solid, extent={{34.0,30.0},{88.0,60.0}}, textString="Tas", fontName="Arial"),Text(visible=true, origin={6.1844,12.2128}, lineColor={0,0,255}, extent={{-122.1844,53.5603},{113.8156,82.0142}}, textString="Heart Intervals", fontName="Arial"),Text(visible=true, lineColor={0,0,255}, extent={{-94.0,12.0},{-30.0,48.0}}, textString="HR", fontName="Arial"),Line(visible=true, points={{-80.0,-6.0},{-80.0,-80.0}}, color={0,0,255}, thickness=0.5),Line(visible=true, points={{-70.0,-6.0},{-70.0,-80.0}}, color={0,0,255}, thickness=0.5),Line(visible=true, points={{-60.0,-6.0},{-60.0,-80.0}}, color={0,0,255}, thickness=0.5),Line(visible=true, points={{-32.0,-6.0},{-32.0,-80.0}}, color={0,0,255}, thickness=0.5),Line(visible=true, points={{30.0,-6.0},{30.0,-80.0}}, color={0,0,255}, thickness=0.5),Line(visible=true, points={{0.0,-6.0},{0.0,-80.0}}, color={0,0,255}, thickness=0.5),Text(visible=true, lineColor={127,0,0}, fillColor={0,0,255}, fillPattern=FillPattern.Solid, extent={{38.0,0.0},{92.0,30.0}}, textString="Tav", fontName="Arial"),Text(visible=true, lineColor={127,0,0}, fillColor={0,0,255}, fillPattern=FillPattern.Solid, extent={{38.0,-34.0},{92.0,-4.0}}, textString="Tvs", fontName="Arial"),Text(visible=true, lineColor={127,0,0}, fillColor={0,0,255}, fillPattern=FillPattern.Solid, extent={{34.0,-68.0},{88.0,-38.0}}, textString="T0", fontName="Arial"),Rectangle(visible=true, fillColor={255,255,255}, extent={{-100.0,-100.0},{100.0,100.0}})}, coordinateSystem(extent={{-100.0,-100.0},{100.0,100.0}}, preserveAspectRatio=true, initialScale=0.1, grid={10,10})));
    end heartIntervals;

    model AtrialElastance
      Modelica.Blocks.Interfaces.RealInput Tas "duration of atrial systole" annotation(Placement(transformation(extent={{-120,12},{-80,52}}), iconTransformation(extent={{-126,62},{-100,88}})));
      Modelica.Blocks.Interfaces.RealOutput Et "elasticity (torr/ml)" annotation(Placement(transformation(extent={{94.0,16.0},{114.0,36.0}}, origin={-1.3229,2.3813}, rotation=0), iconTransformation(extent={{100.0,20.0},{120.0,40.0}}, origin={0.0,0.0}, rotation=0), visible=true));
      Modelica.Blocks.Interfaces.RealInput T0 "time of start of cardiac cycle " annotation(Placement(transformation(extent={{-120,-30},{-80,10}}), iconTransformation(extent={{-126,-54},{-100,-28}})));
      parameter Real EMIN=0.05 "Diastolic elastance (torr/ml)";
      parameter Real EMAX=0.15 "Maximum systolic elastance (tor/ml)";
    equation 
      if time - T0 < Tas then
        Et=EMIN + (EMAX - EMIN)*sin(Modelica.Constants.pi*(time - T0)/Tas);
      else
        Et=EMIN;
      end if annotation(Icon(graphics={Rectangle(extent={{-100,100},{100,-100}}, lineColor={0,0,255}),Text(extent={{-134,122},{126,98}}, lineColor={0,0,255}, textString="%name"),Text(extent={{-122,-34},{-50,-46}}, lineColor={0,0,255}, textString="T0"),Text(extent={{-112,82},{-40,70}}, lineColor={0,0,255}, textString="Tas"),Text(extent={{56,36},{124,24}}, lineColor={0,0,255}, textString="Et"),Text(extent={{-52,62},{116,80}}, lineColor={0,0,255}, textString="Atrial elastance"),Line(points={{-62,-46},{-52,-18},{-36,8},{-16,26},{10,30},{42,2},{62,-42}}, color={0,0,255}, smooth=Smooth.Bezier),Line(points={{62,-42},{86,-42},{100,-42}}, color={0,0,255}, smooth=Smooth.Bezier)}), Diagram(graphics));
      annotation(Icon(graphics={Rectangle(visible=true, fillColor={255,255,255}, extent={{-100.0,-100.0},{100.0,100.0}}),Text(visible=true, origin={-1.1376,11.1636}, fillPattern=FillPattern.Solid, extent={{-88.8624,-11.1636},{88.8624,11.1636}}, textString="Atrial Elastance", fontName="Arial"),Text(visible=true, origin={-73.9995,75.5378}, fillPattern=FillPattern.Solid, extent={{-20.0,-10.0},{20.0,10.0}}, textString="Tas", fontName="Arial"),Text(visible=true, origin={-76.4595,-41.3045}, fillPattern=FillPattern.Solid, extent={{-16.4595,-11.3045},{16.4595,11.3045}}, textString="T0", fontName="Arial"),Text(visible=true, origin={80.0,33.5344}, fillPattern=FillPattern.Solid, extent={{-16.0792,-11.3832},{16.0792,11.3832}}, textString="Et", fontName="Arial")}, coordinateSystem(extent={{-100.0,-100.0},{100.0,100.0}}, preserveAspectRatio=true, initialScale=0.1, grid={10,10})), Diagram(coordinateSystem(extent={{-100.0,-100.0},{100.0,100.0}}, preserveAspectRatio=true, initialScale=0.1, grid={10,10})));
    end AtrialElastance;

    model VentricularElastance
      Modelica.Blocks.Interfaces.RealInput Tas "duration of atrial systole" annotation(Placement(transformation(extent={{-120,12},{-80,52}}), iconTransformation(extent={{-126,62},{-100,88}})));
      Modelica.Blocks.Interfaces.RealOutput Et "elasticity (torr/ml)" annotation(Placement(transformation(extent={{94.0,16.0},{114.0,36.0}}, origin={0.0,0.0}, rotation=0), iconTransformation(extent={{100.0,20.0},{120.0,40.0}}, origin={0.0,10.0}, rotation=0), visible=true));
      Modelica.Blocks.Interfaces.RealInput T0 "time of start of cardiac cycle " annotation(Placement(transformation(extent={{-120,-30},{-80,10}}), iconTransformation(extent={{-126,-54},{-100,-28}})));
      Modelica.Blocks.Interfaces.RealInput Tav "atrioventricular delay" annotation(Placement(transformation(extent={{-120,12},{-80,52}}), iconTransformation(extent={{-126,24},{-100,50}})));
      Modelica.Blocks.Interfaces.RealInput Tvs "duration of ventricular systole" annotation(Placement(transformation(extent={{-120,50},{-80,90}}), iconTransformation(extent={{-126,-14},{-100,12}})));
      Modelica.Blocks.Interfaces.RealOutput Et0 "elasticity (torr/ml)" annotation(Placement(transformation(extent={{94,-8},{114,12}}), iconTransformation(extent={{100,-18},{120,2}})));
      Modelica.Blocks.Interfaces.RealOutput HeartInterval "elasticity (torr/ml)" annotation(Placement(transformation(extent={{96,-30},{116,-10}}), iconTransformation(extent={{100,-50},{120,-30}})));
      constant Real Kn=0.57923032735652;
      parameter Real EMIN=0 "Diastolic elastance (torr/ml)";
      parameter Real EMAX=1 "Maximum systolic elastance (tor/ml)";
    equation 
      HeartInterval=time - T0;
      Et=EMIN + (EMAX - EMIN)*Et0;
      if HeartInterval >= Tas + Tav and HeartInterval < Tas + Tav + Tvs then
        Et0=(HeartInterval - (Tas + Tav))/Tvs*sin(Modelica.Constants.pi*(HeartInterval - (Tas + Tav))/Tvs)/Kn;
      else
        Et0=0;
      end if annotation(Icon(graphics={Rectangle(extent={{-100,100},{100,-100}}, lineColor={0,0,255}),Text(extent={{-134,122},{126,98}}, lineColor={0,0,255}, textString="%name"),Text(extent={{-122,-34},{-50,-46}}, lineColor={0,0,255}, textString="T0"),Text(extent={{-110,48},{-58,34}}, lineColor={0,0,255}, textString="Tav"),Text(extent={{-110,82},{-58,68}}, lineColor={0,0,255}, textString="Tas"),Text(extent={{-112,8},{-60,-6}}, lineColor={0,0,255}, textString="Tvs"),Text(extent={{56,36},{124,24}}, lineColor={0,0,255}, textString="Et"),Text(extent={{-122,-70},{-54,-82}}, lineColor={0,0,255}, textString="Kn"),Text(extent={{-54,62},{114,80}}, lineColor={0,0,255}, textString="Ventricular elastance"),Line(points={{-66,-60},{-54,-32},{-36,0},{0,46},{28,48},{40,0},{56,-60}}, color={0,0,255}, smooth=Smooth.Bezier),Line(points={{56,-60},{90,-60},{100,-60}}, color={0,0,255}, smooth=Smooth.Bezier)}), Diagram(graphics));
      annotation(Icon(coordinateSystem(extent={{-100.0,-100.0},{100.0,100.0}}, preserveAspectRatio=true, initialScale=0.1, grid={10,10}), graphics={Rectangle(visible=true, fillColor={255,255,255}, extent={{-100.0,-100.0},{100.0,100.0}}),Text(visible=true, origin={-1.2605,16.0534}, fillPattern=FillPattern.Solid, extent={{-138.7395,-10.1077},{138.7395,10.1077}}, textString="Ventricular Elastance", fontName="Arial"),Text(visible=true, origin={-82.7938,75.0}, fillPattern=FillPattern.Solid, extent={{-15.0129,-5.0},{15.0129,5.0}}, textString="Tas", fontName="Arial"),Text(visible=true, origin={-83.2397,38.647}, fillPattern=FillPattern.Solid, extent={{-10.1077,-6.8375},{10.1077,6.8375}}, textString="Tav", fontName="Arial"),Text(visible=true, origin={-83.7547,0.0}, fillPattern=FillPattern.Solid, extent={{-11.971,-6.7837},{11.971,6.7837}}, textString="Tvs", fontName="Arial"),Text(visible=true, origin={-83.537,-41.4712}, fillPattern=FillPattern.Solid, extent={{-8.324,-5.7971},{8.324,5.7971}}, textString="T0", fontName="Arial"),Text(visible=true, origin={74.3785,40.4459}, fillPattern=FillPattern.Solid, extent={{-11.155,-6.8223},{11.155,6.8223}}, textString="Et", fontName="Arial"),Text(visible=true, origin={77.0273,-6.8223}, fillPattern=FillPattern.Solid, extent={{-11.155,-6.8223},{11.155,6.8223}}, textString="Et0", fontName="Arial"),Text(visible=true, origin={57.2941,-44.6898}, fillPattern=FillPattern.Solid, extent={{-37.2941,-22.8089},{37.2941,22.8089}}, textString="HeartInterval", fontName="Arial")}), Diagram(graphics));
    end VentricularElastance;

    block Constant "Generate constant signal of type Real"
      parameter Real k(start=1) "Constant output value";
      Modelica.Blocks.Interfaces.RealOutput y annotation(Placement(transformation(extent={{100,-8},{120,12}}), iconTransformation(extent={{100,-8},{120,12}})));
    equation 
      y=k;
      annotation(Icon(coordinateSystem(preserveAspectRatio=true, extent={{-100.0,-100.0},{100.0,100.0}}, grid={2,2}, initialScale=0.04), graphics={Rectangle(visible=true, lineColor={0,0,255}, fillColor={255,255,255}, fillPattern=FillPattern.Solid, extent={{-100.0,-80.0},{100.0,100.0}}),Text(visible=true, fillColor={255,255,255}, fillPattern=FillPattern.Solid, extent={{-100.0,-32.0},{100.0,46.0}}, textString="%k", fontName="Arial"),Text(visible=true, lineColor={0,0,255}, extent={{-176.0,-140.0},{172.0,-106.0}}, textString="%name", fontName="Arial"),Text(visible=true, origin={-7.5,4.3125}, fillPattern=FillPattern.Solid, extent={{-123.5,-50.3125},{123.5,50.3125}}, textString="%k", fontName="Arial")}), Diagram(coordinateSystem(preserveAspectRatio=true, extent={{-100,-100},{100,100}}, grid={2,2}, initialScale=0.04), graphics={Text(extent={{-100,-100},{100,100}}, lineColor={0,0,0}, textString="%k")}), Documentation(info="<html>
<p>
The Real output y is a constant signal:
</p>
</html>"));
    end Constant;

    model CardiacValve
      Haemodynamics.Parts.BloodFlowInflow bloodFlowInflow annotation(Placement(transformation(extent={{-116,-13},{-82,12}}), iconTransformation(extent={{-114,-10},{-86,10}})));
      Haemodynamics.Parts.BloodFlowOutflow bloodFlowOutflow annotation(Placement(transformation(extent={{84,-12},{118,12}}), iconTransformation(extent={{80,-10},{108,10}})));
      Haemodynamics.Parts.Valve outflowValve(open(fixed=true, start=true)) annotation(Placement(transformation(extent={{-40,23},{8,57}})));
      Haemodynamics.Parts.Valve backflowValve(open(fixed=true, start=false)) annotation(Placement(transformation(extent={{10,-60},{-40,-22}})));
      Haemodynamics.Parts.VariableBloodResistor outflowBloodResistor annotation(Placement(transformation(extent={{39,29},{61,51}})));
      Modelica.Blocks.Interfaces.RealInput outflowResistance "in torr sec / ml" annotation(Placement(transformation(extent={{-13,-13},{13,13}}, rotation=0, origin={15,77}), iconTransformation(extent={{-20,-20},{20,20}}, rotation=270, origin={-50,106})));
      Modelica.Blocks.Interfaces.RealInput inflowConductanceValue(start=0) "in ml/sec/torr" annotation(Placement(transformation(extent={{-6,-16},{22,12}}), iconTransformation(extent={{-20,-20},{20,20}}, rotation=270, origin={40,108})));
      Haemodynamics.Parts.VariableBloodConductance variableBloodConductance annotation(Placement(transformation(extent={{60,-52},{38,-30}})));
    equation 
      connect(backflowValve.bloodFlowOutflow,bloodFlowInflow) annotation(Line(points={{-36.25,-40.81},{-80,-40.81},{-80,-0.5},{-99,-0.5}}, color={255,0,0}, thickness=1, smooth=Smooth.None));
      connect(bloodFlowInflow,outflowValve.bloodFlowInflow) annotation(Line(points={{-99,-0.5},{-80,-0.5},{-80,40},{-38.08,40}}, color={255,0,0}, thickness=1, smooth=Smooth.None));
      connect(outflowValve.bloodFlowOutflow,outflowBloodResistor.Inflow) annotation(Line(points={{4.4,40.17},{23.2,40.17},{23.2,40.11},{39,40.11}}, color={255,0,0}, thickness=1, smooth=Smooth.None));
      connect(outflowBloodResistor.Outflow,bloodFlowOutflow) annotation(Line(points={{61,40},{70,40},{70,0},{101,0}}, color={255,0,0}, thickness=1, smooth=Smooth.None));
      connect(outflowResistance,outflowBloodResistor.BloodResistance) annotation(Line(points={{15,77},{50,77},{50,50.1825}}, color={0,0,127}, smooth=Smooth.None));
      connect(inflowConductanceValue,variableBloodConductance.BloodConductance) annotation(Line(points={{8,-2},{49,-2},{49,-30.8175}}, color={0,0,127}, smooth=Smooth.None));
      connect(backflowValve.bloodFlowInflow,variableBloodConductance.Outflow) annotation(Line(points={{8,-41},{38,-41}}, color={255,0,0}, thickness=1, smooth=Smooth.None));
      connect(bloodFlowOutflow,variableBloodConductance.Inflow) annotation(Line(points={{101,0},{70,0},{70,-40.89},{60,-40.89}}, color={255,0,0}, thickness=1, smooth=Smooth.None));
      annotation(Icon(graphics={Polygon(visible=true, fillColor={255,170,170}, fillPattern=FillPattern.Solid, points={{-100.0,100.0},{80.0,0.0},{-100.0,-100.0},{-100.0,100.0}}),Rectangle(visible=true, fillColor={255,170,170}, fillPattern=FillPattern.Solid, extent={{80.0,-100.0},{100.0,100.0}}),Text(visible=true, fillColor={0,0,255}, fillPattern=FillPattern.Solid, extent={{-114.0,-126.0},{108.0,-104.0}}, textString="%name", fontName="Arial")}, coordinateSystem(extent={{-100.0,-100.0},{100.0,100.0}}, preserveAspectRatio=true, initialScale=0.1, grid={10,10})), Diagram(graphics));
    end CardiacValve;

    model RightHeart
      Haemodynamics.Parts.BloodElasticCompartment RightAtrium(V0=40) annotation(Placement(transformation(extent={{-78.0,-70.0},{-32.0,-24.0}}, origin={0.0,2.0}, rotation=0), visible=true));
      Haemodynamics.Parts.Constant VRAU(k=30) annotation(Placement(transformation(extent={{-94.0,-20.0},{-86.0,-12.0}}, origin={0.0,2.0}, rotation=0), visible=true));
      Haemodynamics.Parts.BloodElasticCompartment RightVentricle(V0=130) annotation(Placement(transformation(extent={{11.0,-66.0},{51.0,-26.0}}, origin={0.0,3.0}, rotation=0), visible=true));
      Haemodynamics.Parts.Constant VRVU(k=40) annotation(Placement(transformation(extent={{-12.0,-22.0},{-4.0,-14.0}}, origin={4.0,4.0}, rotation=0), visible=true));
      Haemodynamics.Parts.AtrialElastance rightAtrialElastance(EMIN=0.05, EMAX=0.06) annotation(Placement(transformation(extent={{-44,16},{-10,52}})));
      Haemodynamics.Parts.VentricularElastance rightVentricularElastance(EMIN=0.057, EMAX=0.49) annotation(Placement(transformation(extent={{28.0,16.0},{64.0,52.0}}, origin={2.0,0.0}, rotation=0), visible=true));
      Haemodynamics.Parts.Constant RRAOUT(k=0.003) annotation(Placement(transformation(extent={{-35.0,-80.0},{-25.0,-70.0}}, origin={1.8792,10.0}, rotation=0), visible=true));
      Haemodynamics.Parts.Constant RRV(k=0.003) annotation(Placement(transformation(extent={{95.4865,-98.5667},{107.8073,-86.2458}}, origin={-41.6469,28.5667}, rotation=0), visible=true));
      Haemodynamics.Parts.BloodFlowInflow fromCentralVeins annotation(Placement(transformation(extent={{-116,-90},{-88,-70}}), iconTransformation(extent={{-98,-60},{-68,-38}})));
      Haemodynamics.Parts.BloodFlowOutflow toPulmonaryArtery annotation(Placement(transformation(extent={{94,-90},{122,-70}}), iconTransformation(extent={{76,-54},{106,-32}})));
      Modelica.Blocks.Interfaces.RealInput Tas annotation(Placement(transformation(extent={{-110,74},{-96,88}}), iconTransformation(extent={{-94,56},{-78,72}})));
      Modelica.Blocks.Interfaces.RealInput Tav annotation(Placement(transformation(extent={{0.0,38.0},{14.0,52.0}}, origin={-50.0,25.0}, rotation=0), iconTransformation(extent={{-94.0,36.0},{-78.0,52.0}}, origin={0.0,0.0}, rotation=0), visible=true));
      Modelica.Blocks.Interfaces.RealInput Tvs annotation(Placement(transformation(extent={{0.0,27.0},{14.0,41.0}}, origin={-57.0,26.0}, rotation=0), iconTransformation(extent={{-94.0,16.0},{-78.0,32.0}}, origin={0.0,0.0}, rotation=0), visible=true));
      Modelica.Blocks.Interfaces.RealInput PTH "Intrathoracic pressure (torr)" annotation(Placement(transformation(extent={{-110.0,-2.0},{-96.0,12.0}}, origin={0.0,5.0}, rotation=0), iconTransformation(extent={{-62.0,78.0},{-46.0,94.0}}, origin={0.0,0.0}, rotation=0), visible=true));
      Haemodynamics.Parts.CardiacValve tricuspidValve annotation(Placement(transformation(extent={{-20.0,-90.0},{0.0,-70.0}}, origin={-0.0,0.0}, rotation=0), visible=true));
      Haemodynamics.Parts.CardiacValve pulmonicValve annotation(Placement(transformation(extent={{74.0,-90.0},{94.0,-70.0}}, origin={-6.5264,0.0}, rotation=0), visible=true));
      Haemodynamics.Parts.Constant CRABackflow(k=0) annotation(Placement(transformation(extent={{-22.0,-52.0},{-14.0,-44.0}}, origin={0.4694,2.0}, rotation=0), visible=true));
      Haemodynamics.Parts.Constant CRVBackflow(k=0) annotation(Placement(transformation(extent={{111.0,-78.0},{123.0,-66.0}}, origin={-48.8833,23.7667}, rotation=0), visible=true));
      Modelica.Blocks.Interfaces.RealInput T0 annotation(Placement(transformation(extent={{-100.0,-10.0},{-80.0,10.0}}, origin={0.0,-0.0}, rotation=0), iconTransformation(extent={{-94.0,-4.0},{-78.0,12.0}}, origin={0.0,0.0}, rotation=0), visible=true));
    equation 
      connect(RightAtrium.Elastance,rightAtrialElastance.Et) annotation(Line(visible=true, origin={1.0189,-4.7}, points={{-41.0565,-20.4174},{-41.0189,12.1083},{-5.2522,12.1083},{-5.2522,44.1},{-9.3189,44.1}}, color={0,0,127}));
      connect(T0,rightVentricularElastance.T0) annotation(Line(visible=true, origin={7.1437,0.0}, points={{-97.1437,-0.0},{0.0,0.0},{0.0,26.62},{20.5163,26.62}}, color={0,0,127}));
      connect(VRVU.y,RightVentricle.UnstressedVolume) annotation(Line(visible=true, origin={12.1404,-17.8503}, points={{-11.7404,3.9303},{5.8702,3.9303},{5.8702,-7.8605}}, color={0,0,127}));
      connect(VRAU.y,RightAtrium.UnstressedVolume) annotation(Line(visible=true, origin={-75.1585,-17.6525}, points={{-10.4415,3.7325},{5.2207,3.7325},{5.2207,-7.4649}}, color={0,0,127}));
      connect(Tvs,rightVentricularElastance.Tvs) annotation(Line(visible=true, origin={-8.1469,11.5813}, points={{-41.8531,48.4187},{13.7031,48.4187},{13.7031,22.2387},{35.8069,22.2387}}, color={0,0,127}));
      connect(RightVentricle.Elastance,rightVentricularElastance.Et) annotation(Line(visible=true, points={{44.0107,-25.7108},{44.0107,6.0},{74.0,6.0},{74.0,41.2},{67.8,41.2}}, color={0,0,127}));
      connect(RightVentricle.ExternalPressure,PTH) annotation(Line(visible=true, origin={-12.9929,-0.5703}, points={{45.0036,-21.1405},{45.0036,10.5703},{-90.0071,10.5703}}, color={0,0,127}));
      connect(RightAtrium.ExternalPressure,PTH) annotation(Line(visible=true, origin={-70.2251,-0.1725}, points={{16.3874,-20.3449},{16.3874,10.1725},{-32.7749,10.1725}}, color={0,0,127}));
      connect(rightAtrialElastance.T0,T0) annotation(Line(visible=true, points={{-46.21,26.62},{-78.0,26.62},{-78.0,0.0},{-90.0,0.0}}, color={0,0,127}));
      connect(rightVentricularElastance.Tav,Tav) annotation(Line(visible=true, origin={-1.0583,-1.32}, points={{28.7183,41.98},{11.0583,41.98},{11.0583,71.32},{-41.9417,71.32}}, color={0,0,127}));
      connect(Tas,rightVentricularElastance.Tas) annotation(Line(visible=true, points={{-103.0,81.0},{14.0,81.0},{14.0,47.5},{27.66,47.5}}, color={0,0,127}));
      connect(RightVentricle.bloodFlow,tricuspidValve.bloodFlowOutflow) annotation(Line(visible=true, origin={20.4667,-74.3333}, points={{10.5333,11.3333},{10.5333,-5.6667},{-21.0667,-5.6667}}, color={0,0,255}, thickness=1));
      connect(RightAtrium.bloodFlow,fromCentralVeins) annotation(Line(visible=true, origin={-70.6667,-76.0}, points={{15.6667,8.0},{15.6667,-4.0},{-31.3333,-4.0}}, color={0,0,255}, thickness=1));
      connect(CRABackflow.y,tricuspidValve.inflowConductanceValue) annotation(Line(visible=true, origin={1.3875,1.7639}, points={{-14.5181,-47.6839},{-21.3875,-47.96},{-6.0,-47.96},{-7.3875,-70.9639}}, color={0,0,255}));
      connect(RRAOUT.y,tricuspidValve.outflowResistance) annotation(Line(visible=true, points={{-22.6208,-64.9},{-20.0,-64.9},{-15.0,-64.9},{-15.0,-69.4}}, color={0,0,127}));
      connect(RRV.y,pulmonicValve.outflowResistance) annotation(Line(visible=true, points={{66.7765,-63.7164},{66.7765,-63.7164},{72.4736,-63.7164},{72.4736,-69.4}}, color={0,0,127}));
      connect(CRVBackflow.y,pulmonicValve.inflowConductanceValue) annotation(Line(visible=true, points={{74.7167,-48.1133},{82.4,-47.96},{82.4,-47.96},{81.4736,-69.2}}, color={0,0,127}));
      connect(pulmonicValve.bloodFlowOutflow,toPulmonaryArtery) annotation(Line(visible=true, origin={97.4368,-80.0}, points={{-10.5632,0.0},{10.5632,0.0}}, color={0,0,255}, thickness=1));
      connect(tricuspidValve.bloodFlowOutflow,pulmonicValve.bloodFlowInflow) annotation(Line(visible=true, origin={33.4368,-80.0}, points={{-34.0368,0.0},{34.0368,0.0}}, color={0,0,255}, thickness=1));
      connect(fromCentralVeins,tricuspidValve.bloodFlowInflow) annotation(Line(visible=true, origin={-61.0,-80.0}, points={{-41.0,0.0},{41.0,0.0}}, color={0,0,255}, thickness=1));
      connect(Tas,rightAtrialElastance.Tas) annotation(Line(points={{-103,81},{-58,81},{-58,47.5},{-46.21,47.5}}, color={0,0,127}, smooth=Smooth.None));
      annotation(Diagram(graphics={Text(visible=true, origin={-74.8778,84.3012}, fillPattern=FillPattern.Solid, extent={{-21.1674,-4.3012},{21.1674,4.3012}}, textString="duration of atrial systole", fontName="Arial"),Text(visible=true, origin={-14.0515,72.3062}, fillPattern=FillPattern.Solid, extent={{-20.4464,-3.8937},{20.4464,3.8937}}, textString="atrioventricular delay", fontName="Arial"),Text(visible=true, origin={-20.0,63.7344}, fillPattern=FillPattern.Solid, extent={{-25.4525,-3.7344},{25.4525,3.7344}}, textString="duration of ventricular systole", fontName="Arial"),Text(visible=true, origin={-14.4903,2.6458}, fillPattern=FillPattern.Solid, extent={{-21.1674,-4.3012},{21.1674,4.3012}}, textString="start time of cardiac cycle ", fontName="Arial"),Text(visible=true, origin={-51.1674,12.7137}, fillPattern=FillPattern.Solid, extent={{-21.1674,-4.3012},{21.1674,4.3012}}, textString="Intrathoracic pressure", fontName="Arial")}, coordinateSystem(extent={{-100.0,-100.0},{100.0,100.0}}, preserveAspectRatio=true, initialScale=0.1, grid={10,10})), Icon(graphics={Ellipse(visible=true, lineColor={0,0,255}, fillColor={255,170,170}, fillPattern=FillPattern.Solid, extent={{-100.0,-100.0},{100.0,100.0}}),Text(visible=true, lineColor={0,0,255}, fillColor={255,170,170}, fillPattern=FillPattern.Solid, extent={{-50.0,8.0},{84.0,36.0}}, textString="Right Heart", fontName="Arial"),Text(visible=true, lineColor={0,0,255}, fillColor={0,0,255}, extent={{-94.0,56.0},{-42.0,72.0}}, textString="Tas", fontName="Arial"),Text(visible=true, lineColor={0,0,255}, fillColor={0,0,255}, extent={{-94.0,38.0},{-42.0,54.0}}, textString="Tav", fontName="Arial"),Text(visible=true, lineColor={0,0,255}, fillColor={0,0,255}, extent={{-92.0,16.0},{-40.0,32.0}}, textString="Tvs", fontName="Arial"),Text(visible=true, lineColor={0,0,255}, fillColor={0,0,255}, extent={{-90.0,-2.0},{-38.0,14.0}}, textString="T0", fontName="Arial"),Text(visible=true, lineColor={0,0,255}, fillColor={255,170,170}, fillPattern=FillPattern.Solid, extent={{-90.0,-24.0},{-38.0,-8.0}}, textString="Kn", fontName="Arial"),Text(visible=true, lineColor={0,0,255}, fillColor={0,0,255}, extent={{-58.0,78.0},{-6.0,94.0}}, textString="PTH", fontName="Arial")}, coordinateSystem(extent={{-100.0,-100.0},{100.0,100.0}}, preserveAspectRatio=true, initialScale=0.1, grid={10,10})));
    end RightHeart;

    model LeftHeart
      import CirculationEducational;
      Haemodynamics.Parts.BloodElasticCompartment LeftAtrium(V0=40) annotation(Placement(transformation(extent={{-82,-70},{-36,-24}})));
      Haemodynamics.Parts.Constant VLAU(k=30) annotation(Placement(transformation(extent={{-94,-20},{-86,-12}})));
      Haemodynamics.Parts.BloodElasticCompartment LeftVentricle(V0=130) annotation(Placement(transformation(extent={{16,-66},{56,-26}})));
      Haemodynamics.Parts.Constant VLVU(k=60) annotation(Placement(transformation(extent={{-12,-22},{-4,-14}})));
      Haemodynamics.Parts.AtrialElastance leftAtrialElastance(EMIN=0.12, EMAX=0.28) annotation(Placement(transformation(extent={{-44,20},{-10,56}})));
      Haemodynamics.Parts.VentricularElastance leftVentricularElastance(EMIN=0.09, EMAX=4) annotation(Placement(transformation(extent={{28,18},{64,54}})));
      Haemodynamics.Parts.Constant RLAOUT(k=0.003) annotation(Placement(transformation(extent={{-26,-52},{-18,-44}})));
      Haemodynamics.Parts.Constant RLV(k=0.008) annotation(Placement(transformation(extent={{62,-48},{70,-40}})));
      Haemodynamics.Parts.BloodFlowInflow fromPulmonaryVeins annotation(Placement(transformation(extent={{-116,-91},{-84,-69}}), iconTransformation(extent={{-98,-60},{-68,-38}})));
      Haemodynamics.Parts.BloodFlowOutflow toAorta annotation(Placement(transformation(extent={{94,-91},{126,-69}}), iconTransformation(extent={{76,-54},{106,-32}})));
      Modelica.Blocks.Interfaces.RealInput Tas annotation(Placement(transformation(extent={{-110,74},{-96,88}}), iconTransformation(extent={{-94,56},{-78,72}})));
      Modelica.Blocks.Interfaces.RealInput Tav annotation(Placement(transformation(extent={{0.0,38.0},{14.0,52.0}}, origin={-47.0,25.0}, rotation=0), iconTransformation(extent={{-94.0,36.0},{-78.0,52.0}}, origin={0.0,0.0}, rotation=0), visible=true));
      Modelica.Blocks.Interfaces.RealInput Tvs annotation(Placement(transformation(extent={{0.0,27.0},{14.0,41.0}}, origin={-54.0,29.0}, rotation=0), iconTransformation(extent={{-94.0,16.0},{-78.0,32.0}}, origin={0.0,0.0}, rotation=0), visible=true));
      Modelica.Blocks.Interfaces.RealInput T0 annotation(Placement(transformation(extent={{-112.0,62.0},{-98.0,76.0}}, origin={-2.0,-12.0}, rotation=0), iconTransformation(extent={{-94.0,-4.0},{-78.0,12.0}}, origin={0.0,0.0}, rotation=0), visible=true));
      Modelica.Blocks.Interfaces.RealInput PTH "Intrathoracic pressure (torr)" annotation(Placement(transformation(extent={{-110,-2},{-96,12}}), iconTransformation(extent={{-62,78},{-46,94}})));
      Haemodynamics.Parts.CardiacValve aorticValve annotation(Placement(transformation(extent={{70,-90},{90,-70}})));
      Haemodynamics.Parts.Constant CLVBackflow(k=0) annotation(Placement(transformation(extent={{-4,-4},{4,4}}, rotation=180, origin={90,-50})));
      Haemodynamics.Parts.CardiacValve tricuspidValve annotation(Placement(transformation(extent={{-18,-90},{2,-70}})));
      Haemodynamics.Parts.Constant RLABackflow(k=0) annotation(Placement(transformation(extent={{-4,-4},{4,4}}, rotation=180, origin={4,-54})));
    equation 
      connect(LeftAtrium.ExternalPressure,PTH) annotation(Line(visible=true, origin={-0.1323,0.1323}, points={{-57.7054,-22.6497},{-57.8377,5.0},{-102.8677,4.8677}}, color={0,0,127}));
      connect(Tvs,leftVentricularElastance.Tvs) annotation(Line(visible=true, origin={-9.1281,0.2646}, points={{-37.8719,62.7354},{15.5,62.7354},{15.5,35.82},{34.7881,35.5554}}, color={0,0,127}));
      connect(leftVentricularElastance.Tav,Tav) annotation(Line(visible=true, origin={-8.0,25.0}, points={{33.66,17.66},{18.0,17.66},{18.0,45.0},{-32.0,45.0}}, color={0,0,127}));
      connect(leftAtrialElastance.T0,T0) annotation(Line(visible=true, origin={-2.0,-10.62}, points={{-44.21,41.24},{-78.0,41.24},{-78.0,67.62},{-105.0,67.62}}, color={0,0,127}));
      connect(T0,leftVentricularElastance.T0) annotation(Line(visible=true, origin={0.0,-10.869}, points={{-107.0,67.869},{0.0,69.0},{0.0,39.489},{25.66,39.489}}, color={0,0,127}));
      connect(Tas,leftAtrialElastance.Tas) annotation(Line(visible=true, origin={2.4805,-1.0}, points={{-105.4805,82.0},{-58.0,82.0},{-58.0,52.5},{-48.6905,52.5}}, color={0,0,127}));
      connect(VLAU.y,LeftAtrium.UnstressedVolume) annotation(Line(points={{-85.6,-15.92},{-73.9378,-15.92},{-73.9378,-27.1174}}, color={0,0,127}, smooth=Smooth.None));
      connect(VLVU.y,LeftVentricle.UnstressedVolume) annotation(Line(points={{-3.6,-17.92},{23.0106,-17.92},{23.0106,-28.7108}}, color={0,0,127}, smooth=Smooth.None));
      connect(LeftAtrium.Elastance,leftAtrialElastance.Et) annotation(Line(points={{-44.0377,-27.1174},{-44.0377,10},{-2,10},{-2,43.4},{-8.3,43.4}}, color={0,0,127}, smooth=Smooth.None));
      connect(LeftVentricle.Elastance,leftVentricularElastance.Et) annotation(Line(points={{49.0107,-28.7108},{49.0107,10},{74,10},{74,41.4},{65.8,41.4}}, color={0,0,127}, smooth=Smooth.None));
      connect(Tas,leftVentricularElastance.Tas) annotation(Line(points={{-103,81},{14,81},{14,49.5},{25.66,49.5}}, color={0,0,127}, smooth=Smooth.None));
      connect(LeftVentricle.ExternalPressure,PTH) annotation(Line(points={{37.0107,-24.7108},{37.0107,5},{-103,5}}, color={0,0,127}, smooth=Smooth.None));
      connect(LeftVentricle.bloodFlow,aorticValve.bloodFlowInflow) annotation(Line(points={{36,-66},{36,-80},{70,-80}}, color={255,0,0}, thickness=1, smooth=Smooth.None));
      connect(aorticValve.bloodFlowOutflow,toAorta) annotation(Line(points={{89.4,-80},{110,-80}}, color={255,0,0}, thickness=1, smooth=Smooth.None));
      connect(RLV.y,aorticValve.outflowResistance) annotation(Line(points={{70.4,-43.92},{75,-43.92},{75,-69.4}}, color={0,0,127}, smooth=Smooth.None));
      connect(CLVBackflow.y,aorticValve.inflowConductanceValue) annotation(Line(points={{85.6,-50.08},{84,-50.08},{84,-69.2}}, color={0,0,127}, smooth=Smooth.None));
      connect(tricuspidValve.bloodFlowOutflow,aorticValve.bloodFlowInflow) annotation(Line(points={{1.4,-80},{70,-80}}, color={255,0,0}, thickness=1, smooth=Smooth.None));
      connect(RLAOUT.y,tricuspidValve.outflowResistance) annotation(Line(points={{-17.6,-47.92},{-13,-47.92},{-13,-69.4}}, color={0,0,0}, smooth=Smooth.None));
      connect(RLABackflow.y,tricuspidValve.inflowConductanceValue) annotation(Line(points={{-0.4,-54.08},{-4,-54.08},{-4,-69.2}}, color={0,0,0}, smooth=Smooth.None));
      connect(fromPulmonaryVeins,tricuspidValve.bloodFlowInflow) annotation(Line(points={{-100,-80},{-18,-80}}, color={255,0,0}, thickness=1, smooth=Smooth.None));
      connect(fromPulmonaryVeins,LeftAtrium.bloodFlow) annotation(Line(points={{-100,-80},{-59,-80},{-59,-70}}, color={255,0,0}, thickness=1, smooth=Smooth.None));
      annotation(Diagram(graphics={Text(visible=true, origin={-78.8326,60.0}, fillPattern=FillPattern.Solid, extent={{-21.1674,-4.3012},{21.1674,4.3012}}, textString="start time of cardiac cycle ", fontName="Arial"),Text(visible=true, origin={-75.8038,84.3012}, fillPattern=FillPattern.Solid, extent={{-21.1674,-4.3012},{21.1674,4.3012}}, textString="duration of atrial systole", fontName="Arial"),Text(visible=true, origin={-17.2738,65.0542}, fillPattern=FillPattern.Solid, extent={{-22.7262,-3.3344},{22.7262,3.3344}}, textString="duration of ventricular systole", fontName="Arial"),Text(visible=true, origin={-18.0427,71.5462}, fillPattern=FillPattern.Solid, extent={{-16.4552,-3.1337},{16.4552,3.1337}}, textString="atrioventricular delay", fontName="Arial"),Text(visible=true, origin={-73.2601,8.08}, fillPattern=FillPattern.Solid, extent={{-21.1674,-4.3012},{21.1674,4.3012}}, textString="Intrathoracic pressure", fontName="Arial")}, coordinateSystem(extent={{-100.0,-100.0},{100.0,100.0}}, preserveAspectRatio=true, initialScale=0.1, grid={10,10})), Icon(graphics={Ellipse(visible=true, lineColor={0,0,255}, fillColor={255,170,170}, fillPattern=FillPattern.Solid, extent={{-100.0,-100.0},{100.0,100.0}}),Text(visible=true, lineColor={0,0,255}, fillColor={255,170,170}, fillPattern=FillPattern.Solid, extent={{-50.0,8.0},{84.0,36.0}}, textString="Left Heart", fontName="Arial"),Text(visible=true, lineColor={0,0,255}, fillColor={0,0,255}, extent={{-94.0,56.0},{-42.0,72.0}}, textString="Tas", fontName="Arial"),Text(visible=true, lineColor={0,0,255}, fillColor={0,0,255}, extent={{-94.0,38.0},{-42.0,54.0}}, textString="Tav", fontName="Arial"),Text(visible=true, lineColor={0,0,255}, fillColor={0,0,255}, extent={{-92.0,16.0},{-40.0,32.0}}, textString="Tvs", fontName="Arial"),Text(visible=true, lineColor={0,0,255}, fillColor={0,0,255}, extent={{-90.0,-2.0},{-38.0,14.0}}, textString="T0", fontName="Arial"),Text(visible=true, lineColor={0,0,255}, fillColor={255,170,170}, fillPattern=FillPattern.Solid, extent={{-90.0,-24.0},{-38.0,-8.0}}, textString="Kn", fontName="Arial"),Text(visible=true, lineColor={0,0,255}, fillColor={0,0,255}, extent={{-58.0,78.0},{-6.0,94.0}}, textString="PTH", fontName="Arial")}, coordinateSystem(extent={{-100.0,-100.0},{100.0,100.0}}, preserveAspectRatio=true, initialScale=0.1, grid={10,10})));
    end LeftHeart;

    model SystemicArteries
      Haemodynamics.Parts.BloodElasticCompartment ExtrathoracicArteries(V0=450) annotation(Placement(transformation(extent={{-90,-40},{-42,8}})));
      Haemodynamics.Parts.BloodElasticCompartment IntrathoracicArteries(V0=300) annotation(Placement(transformation(extent={{38,-44},{86,4}})));
      Haemodynamics.Parts.VariableBloodResistor ExtrathoracicArterialResistance annotation(Placement(transformation(extent={{-13,-13},{13,13}}, rotation=180, origin={-21,-55})));
      Haemodynamics.Parts.Constant VITHAU(k=140) "unstressed volume in ml" annotation(Placement(transformation(extent={{4,12},{16,24}})));
      Haemodynamics.Parts.Constant EITHA(k=1.43) "elastance (torr/ml)" annotation(Placement(transformation(extent={{-6,-6},{6,6}}, rotation=180, origin={98,26})));
      Haemodynamics.Parts.Constant Pext(k=0) "unstressed volume in ml" annotation(Placement(transformation(extent={{-82,36},{-70,48}})));
      Haemodynamics.Parts.Constant RETHA(k=0.06) "resistance torr sec/ml" annotation(Placement(transformation(extent={{-68,-92},{-56,-80}})));
      Haemodynamics.Parts.Constant VETHAU(k=370) "unstressed volume in ml" annotation(Placement(transformation(extent={{-102,28},{-90,40}})));
      Haemodynamics.Parts.Constant EETHA(k=0.556) "elastance (torr/ml)" annotation(Placement(transformation(extent={{-6,-6},{6,6}}, rotation=180, origin={-18,18})));
      Haemodynamics.Parts.BloodFlowOutflow bloodFlowOutflow annotation(Placement(transformation(extent={{-118,-65},{-88,-45}}), iconTransformation(extent={{-124,-17},{-94,3}})));
      Haemodynamics.Parts.BloodFlowInflow bloodFlowInflow annotation(Placement(transformation(extent={{86,-65},{116,-45}}), iconTransformation(extent={{94,-17},{124,3}})));
      Modelica.Blocks.Interfaces.RealInput IntrathoracicPresssure "in torr" annotation(Placement(visible=true, transformation(origin={-84,75.9868}, extent={{-14,-14.0132},{14,14.0132}}, rotation=0), iconTransformation(origin={12,48}, extent={{-8,-8},{8,8}}, rotation=-90)));
      Haemodynamics.Parts.Inductor BloodFlowInertia annotation(Placement(transformation(extent={{44,-74},{6,-36}})));
      Haemodynamics.Parts.Constant LETHA(k=0.0007) "inertance in torr sec^2/ml" annotation(Placement(transformation(extent={{-22,-22},{-10,-10}})));
    equation 
      connect(ExtrathoracicArterialResistance.Outflow,ExtrathoracicArteries.bloodFlow) annotation(Line(points={{-34,-55},{-66,-55},{-66,-40}}, color={255,0,0}, smooth=Smooth.None, thickness=1));
      connect(VITHAU.y,IntrathoracicArteries.UnstressedVolume) annotation(Line(points={{16.6,18.12},{32,12},{34,20},{46,16},{46,0.74704},{46.4127,0.74704}}, color={0,0,127}, smooth=Smooth.Bezier));
      connect(IntrathoracicArteries.Elastance,EITHA.y) annotation(Line(points={{77.6128,0.74704},{77.6128,25.88},{91.4,25.88}}, color={0,0,127}, smooth=Smooth.Bezier));
      connect(RETHA.y,ExtrathoracicArterialResistance.BloodResistance) annotation(Line(points={{-55.4,-85.88},{-22.7,-85.88},{-22.7,-67.0339},{-21,-67.0339}}, color={0,0,127}, smooth=Smooth.Bezier));
      connect(VETHAU.y,ExtrathoracicArteries.UnstressedVolume) annotation(Line(points={{-89.4,34.12},{-89.4,35.06},{-81.5873,35.06},{-81.5873,4.74704}}, color={0,0,127}, smooth=Smooth.Bezier));
      connect(EETHA.y,ExtrathoracicArteries.Elastance) annotation(Line(points={{-24.6,17.88},{-24.6,17.94},{-50.3872,17.94},{-50.3872,4.74704}}, color={0,0,127}, smooth=Smooth.Bezier));
      connect(IntrathoracicArteries.bloodFlow,bloodFlowInflow) annotation(Line(points={{62,-44},{62,-55},{101,-55}}, color={255,0,0}, smooth=Smooth.None, thickness=1));
      connect(ExtrathoracicArteries.bloodFlow,bloodFlowOutflow) annotation(Line(points={{-66,-40},{-66,-55},{-103,-55}}, color={255,0,0}, thickness=1, smooth=Smooth.None));
      connect(BloodFlowInertia.Inflow,IntrathoracicArteries.bloodFlow) annotation(Line(points={{44,-54.81},{62,-54.81},{62,-44}}, color={255,0,0}, smooth=Smooth.None, thickness=1));
      connect(ExtrathoracicArterialResistance.Inflow,BloodFlowInertia.Outflow) annotation(Line(points={{-8,-55.13},{-4,-56},{-4,-55},{6,-55}}, color={255,0,0}, thickness=1, smooth=Smooth.None));
      connect(IntrathoracicPresssure,IntrathoracicArteries.ExternalPressure) annotation(Line(points={{-84,75.9868},{62,75.9868},{62,5.54704},{63.2128,5.54704}}, color={0,0,127}, smooth=Smooth.Bezier));
      connect(Pext.y,ExtrathoracicArteries.ExternalPressure) annotation(Line(points={{-69.4,42.12},{-69.4,42.06},{-64.7872,42.06},{-64.7872,9.54704}}, color={0,0,127}, smooth=Smooth.Bezier));
      connect(LETHA.y,BloodFlowInertia.Inertance) annotation(Line(points={{-9.4,-15.88},{25,-15.88},{25,-39.312}}, color={0,0,127}, smooth=Smooth.None));
      annotation(Diagram(graphics), Icon(graphics={Ellipse(extent={{92,46},{110,-44}}, lineColor={0,0,255}, fillColor={255,0,0}, fillPattern=FillPattern.Solid),Rectangle(extent={{-100,46},{102,-44}}, fillColor={255,0,0}, fillPattern=FillPattern.Solid, pattern=LinePattern.None, lineColor={0,0,0}),Ellipse(extent={{-110,46},{-92,-44}}, lineColor={0,0,255}, fillColor={0,0,255}, fillPattern=FillPattern.Solid),Text(extent={{-106,-56},{112,-86}}, lineColor={0,0,255}, fillColor={0,0,255}, fillPattern=FillPattern.Solid, textString="%name"),Text(extent={{110,24},{-92,34}}, lineColor={0,0,0}, lineThickness=1, textString="intrathoracic pressure", fillPattern=FillPattern.Solid, fillColor={255,0,0})}));
    end SystemicArteries;

    model SystemicPeripheralVessels
      Haemodynamics.Parts.BloodFlowOutflow bloodFlowOutflow annotation(Placement(transformation(extent={{-114,10},{-84,30}}), iconTransformation(extent={{-110,10},{-80,30}})));
      Haemodynamics.Parts.BloodFlowInflow bloodFlowInflow annotation(Placement(transformation(extent={{82,9},{112,31}}), iconTransformation(extent={{80,8},{110,30}})));
      Haemodynamics.Parts.VariableBloodResistor SmallVenuleResistances annotation(Placement(transformation(extent={{-24,5},{-52,34}})));
      Modelica.Blocks.Interfaces.RealInput PeripheralArteriolarResistance "in torr sec/ml" annotation(Placement(visible=true, transformation(origin={109,51}, extent={{17,-17},{-17,17}}, rotation=0), iconTransformation(origin={-10,98}, extent={{-8,-8},{8,8}}, rotation=-90)));
      Haemodynamics.Parts.BloodElasticCompartment BloodTissueElasticCompartment(V0=200) annotation(Placement(transformation(extent={{10,36},{54,80}})));
      Haemodynamics.Parts.Constant TUV(k=185) "unstressed volume in ml" annotation(Placement(transformation(extent={{-28,86},{-16,98}})));
      Haemodynamics.Parts.Constant Pext(k=0) "unstressed volume in ml" annotation(Placement(transformation(extent={{54,88},{44,98}})));
      Haemodynamics.Parts.Constant EET(k=0.262) "elastance (torr/ml)" annotation(Placement(transformation(extent={{-6,-6},{6,6}}, rotation=180, origin={80,84})));
      Haemodynamics.Parts.VariableBloodResistor SystemicArteriolaResistance annotation(Placement(transformation(extent={{74,6},{46,35}})));
      Haemodynamics.Parts.Constant RTA(k=0.2) "resistance torr sec/ml" annotation(Placement(transformation(extent={{5,-5},{-5,5}}, rotation=180, origin={-69,47})));
    equation 
      connect(SmallVenuleResistances.Outflow,bloodFlowOutflow) annotation(Line(points={{-52,19.5},{-76,19.5},{-76,20},{-99,20}}, color={0,0,255}, smooth=Smooth.None, thickness=1));
      connect(SmallVenuleResistances.Inflow,BloodTissueElasticCompartment.bloodFlow) annotation(Line(points={{-24,19.645},{10,19.645},{10,20},{32,20},{32,36}}, color={255,0,0}, thickness=1, smooth=Smooth.None));
      connect(BloodTissueElasticCompartment.UnstressedVolume,TUV.y) annotation(Line(points={{17.7117,77.0181},{17.7117,92.12},{-15.4,92.12}}, color={0,0,127}, smooth=Smooth.None));
      connect(BloodTissueElasticCompartment.ExternalPressure,Pext.y) annotation(Line(points={{33.1118,81.4181},{33.1118,93.1},{43.5,93.1}}, color={0,0,127}, smooth=Smooth.None));
      connect(EET.y,BloodTissueElasticCompartment.Elastance) annotation(Line(points={{73.4,83.88},{60,84},{46,84},{46,77.0181},{46.3118,77.0181}}, color={0,0,127}, smooth=Smooth.None));
      connect(SystemicArteriolaResistance.Inflow,bloodFlowInflow) annotation(Line(points={{74,20.645},{85,20.645},{85,20},{97,20}}, color={255,0,0}, smooth=Smooth.None, thickness=1));
      connect(SystemicArteriolaResistance.Outflow,BloodTissueElasticCompartment.bloodFlow) annotation(Line(points={{46,20.5},{40,20.5},{40,20},{32,20},{32,36}}, color={255,0,0}, smooth=Smooth.None, thickness=1));
      connect(PeripheralArteriolarResistance,SystemicArteriolaResistance.BloodResistance) annotation(Line(points={{109,51},{60,51},{60,33.9224}}, color={0,0,127}, smooth=Smooth.None));
      connect(RTA.y,SmallVenuleResistances.BloodResistance) annotation(Line(points={{-63.5,46.9},{-38,46.9},{-38,32.9224}}, color={0,0,127}, smooth=Smooth.None));
      annotation(Icon(graphics={Line(points={{100,20},{46,58},{22,66},{-34,64},{-60,40},{-100,20},{-60,32},{-38,54},{-2,56},{36,50},{82,30},{100,20},{20,46},{-26,48},{-54,30},{-100,20},{-52,24},{-20,40},{28,36},{100,20},{34,28},{-18,28},{-54,20},{-100,20},{-54,14},{-20,16},{32,18},{100,20},{66,6},{-26,4},{-70,8},{-100,20},{-70,0},{2,-6},{60,-2},{100,20},{54,-14},{-38,-16},{-78,-6},{-100,20},{-72,-22},{30,-34},{64,-18},{100,20},{66,-30},{24,-46},{-48,-40},{-72,-34},{-100,20},{-78,-62},{-4,-76},{74,-68},{100,20},{62,-54},{0,-60},{-78,-46},{-100,20},{-58,70},{2,74},{50,68},{100,20},{56,84},{2,90},{-50,86},{-78,64},{-100,20}}, color={255,0,0}, smooth=Smooth.None, thickness=0.5),Text(extent={{-120,-78},{124,-106}}, lineColor={0,0,255}, fillColor={0,0,255}, fillPattern=FillPattern.Solid, textString="%name"),Text(extent={{102,76},{-100,86}}, lineColor={0,0,0}, lineThickness=1, fillPattern=FillPattern.Solid, fillColor={255,0,0}, textString="peripheral resistance")}), Diagram(graphics));
    end SystemicPeripheralVessels;

    model SystemicVeins
      Haemodynamics.Parts.BloodElasticCompartment IntrathoracicVeins(V0=2000) annotation(Placement(transformation(extent={{-72,-40},{-24,8}})));
      Haemodynamics.Parts.BloodElasticCompartment ExtrathoracicVeins(V0=1900) annotation(Placement(transformation(extent={{22,-42},{70,6}})));
      Haemodynamics.Parts.VariableBloodResistor VeinsResistance annotation(Placement(transformation(extent={{-13,-13},{13,13}}, rotation=180, origin={-5,-55})));
      Haemodynamics.Parts.Constant VETHVU(k=1000) "unstressed volume in ml" annotation(Placement(transformation(extent={{2,10},{14,22}})));
      Haemodynamics.Parts.Constant EETHV(k=0.0169) "elastance (torr/ml)" annotation(Placement(transformation(extent={{-6,-6},{6,6}}, rotation=180, origin={88,26})));
      Haemodynamics.Parts.Constant Pext(k=0) "unstressed volume in ml" annotation(Placement(transformation(extent={{26,24},{38,36}})));
      Haemodynamics.Parts.Constant RETHV(k=0.09) "resistance torr sec/ml" annotation(Placement(transformation(extent={{-40,-92},{-28,-80}})));
      Haemodynamics.Parts.Constant VITHVU(k=1190) "unstressed volume in ml" annotation(Placement(transformation(extent={{-96,22},{-84,34}})));
      Haemodynamics.Parts.Constant EITHV(k=0.0182) "elastance (torr/ml)" annotation(Placement(transformation(extent={{-6,-6},{6,6}}, rotation=180, origin={-18,18})));
      Haemodynamics.Parts.BloodFlowOutflow bloodFlowOutflow annotation(Placement(transformation(extent={{-116,-65},{-86,-45}}), iconTransformation(extent={{-124,-17},{-94,3}})));
      Haemodynamics.Parts.BloodFlowInflow bloodFlowInflow annotation(Placement(transformation(extent={{86,-65},{116,-45}}), iconTransformation(extent={{94,-17},{124,3}})));
      Modelica.Blocks.Interfaces.RealInput IntrathoracicPresssure "in torr" annotation(Placement(visible=true, transformation(origin={-82,51.9868}, extent={{-14,-14.0132},{14,14.0132}}, rotation=0), iconTransformation(origin={12,48}, extent={{-8,-8},{8,8}}, rotation=-90)));
      Haemodynamics.Parts.Constant RRAIN(k=0.003) annotation(Placement(transformation(extent={{-4,-4},{4,4}}, rotation=0, origin={-92,-84})));
      Haemodynamics.Parts.VariableBloodResistor centralVenousResistance annotation(Placement(transformation(extent={{-10,-10},{10,10}}, rotation=180, origin={-76,-55})));
    equation 
      connect(VeinsResistance.Inflow,ExtrathoracicVeins.bloodFlow) annotation(Line(points={{8,-55.13},{46,-55.13},{46,-42}}, color={0,0,255}, smooth=Smooth.None, thickness=1));
      connect(VeinsResistance.Outflow,IntrathoracicVeins.bloodFlow) annotation(Line(points={{-18,-55},{-48,-55},{-48,-40}}, color={0,0,255}, smooth=Smooth.None, thickness=1));
      connect(ExtrathoracicVeins.Elastance,EETHV.y) annotation(Line(points={{61.6128,2.74704},{61.6128,25.88},{81.4,25.88}}, color={0,0,127}, smooth=Smooth.Bezier));
      connect(Pext.y,ExtrathoracicVeins.ExternalPressure) annotation(Line(points={{38.6,30.12},{38.6,31.06},{47.2128,31.06},{47.2128,7.54704}}, color={0,0,127}, smooth=Smooth.Bezier));
      connect(RETHV.y,VeinsResistance.BloodResistance) annotation(Line(points={{-27.4,-85.88},{-4.7,-85.88},{-4.7,-67.0339},{-5,-67.0339}}, color={0,0,127}, smooth=Smooth.Bezier));
      connect(EITHV.y,IntrathoracicVeins.Elastance) annotation(Line(points={{-24.6,17.88},{-24.6,17.94},{-32.3872,17.94},{-32.3872,4.74704}}, color={0,0,127}, smooth=Smooth.Bezier));
      connect(IntrathoracicVeins.ExternalPressure,IntrathoracicPresssure) annotation(Line(points={{-46.7872,9.54704},{-46,40},{-46,51.9868},{-82,51.9868}}, color={0,0,127}, smooth=Smooth.Bezier));
      connect(ExtrathoracicVeins.UnstressedVolume,VETHVU.y) annotation(Line(points={{30.4127,2.74704},{30.4127,16.12},{14.6,16.12}}, color={0,0,127}, smooth=Smooth.Bezier));
      connect(VeinsResistance.Inflow,bloodFlowInflow) annotation(Line(points={{8,-55.13},{54,-55.13},{54,-55},{101,-55}}, color={0,0,255}, thickness=1, smooth=Smooth.None));
      connect(RRAIN.y,centralVenousResistance.BloodResistance) annotation(Line(points={{-87.6,-83.92},{-76,-83.92},{-76,-64.2569}}, color={0,0,127}, smooth=Smooth.Bezier));
      connect(VITHVU.y,IntrathoracicVeins.UnstressedVolume) annotation(Line(points={{-83.4,28.12},{-64,28.12},{-64,4.74704},{-63.5873,4.74704}}, color={0,0,127}, smooth=Smooth.Bezier));
      connect(bloodFlowOutflow,centralVenousResistance.Outflow) annotation(Line(points={{-101,-55},{-86,-55}}, color={0,0,255}, thickness=1, smooth=Smooth.None));
      connect(centralVenousResistance.Inflow,VeinsResistance.Outflow) annotation(Line(points={{-66,-55.1},{-58,-55.1},{-58,-55},{-18,-55}}, color={0,0,255}, thickness=1, smooth=Smooth.None));
      annotation(Diagram(graphics), Icon(graphics={Ellipse(extent={{92,46},{110,-44}}, lineColor={0,0,255}, fillColor={0,128,255}, fillPattern=FillPattern.Solid),Rectangle(extent={{-100,46},{102,-44}}, fillColor={0,128,255}, fillPattern=FillPattern.Solid, pattern=LinePattern.None),Ellipse(extent={{-110,46},{-92,-44}}, lineColor={0,0,255}, fillColor={0,0,255}, fillPattern=FillPattern.Solid),Text(extent={{-106,-56},{112,-86}}, lineColor={0,0,255}, fillColor={0,0,255}, fillPattern=FillPattern.Solid, textString="%name"),Text(extent={{110,24},{-92,34}}, lineColor={0,0,0}, lineThickness=1, textString="intrathoracic pressure")}));
    end SystemicVeins;

    model PulmonaryCirculation
      Haemodynamics.Parts.BloodElasticCompartment PulmonaryArteries(V0=100) annotation(Placement(transformation(extent={{-90,-40},{-42,8}})));
      Haemodynamics.Parts.BloodElasticCompartment PulmonaryVeins(V0=600) annotation(Placement(transformation(extent={{10,-44},{58,4}})));
      Haemodynamics.Parts.VariableBloodResistor PulmonaryArteriesResistance annotation(Placement(transformation(extent={{13,-13},{-13,13}}, rotation=180, origin={-27,-60})));
      Haemodynamics.Parts.Constant VPVU(k=350) "unstressed volume in ml" annotation(Placement(transformation(extent={{-4,16},{8,28}})));
      Haemodynamics.Parts.Constant EPV(k=0.0455) "elastance (torr/ml)" annotation(Placement(transformation(extent={{-6,-6},{6,6}}, rotation=180, origin={78,26})));
      Haemodynamics.Parts.Constant RPP(k=0.11) "resistance torr sec/ml" annotation(Placement(transformation(extent={{-44,-92},{-32,-80}})));
      Haemodynamics.Parts.Constant VPAU(k=50) "unstressed volume in ml" annotation(Placement(transformation(extent={{-102,28},{-90,40}})));
      Haemodynamics.Parts.Constant EPA(k=0.233) "elastance (torr/ml)" annotation(Placement(transformation(extent={{-6,-6},{6,6}}, rotation=180, origin={-18,18})));
      Haemodynamics.Parts.BloodFlowOutflow bloodFlowOutflow annotation(Placement(transformation(extent={{88,-70},{118,-50}}), iconTransformation(extent={{102,-13},{132,7}})));
      Haemodynamics.Parts.BloodFlowInflow bloodFlowInflow annotation(Placement(transformation(extent={{-116,-70},{-86,-50}}), iconTransformation(extent={{-128,-9},{-98,11}})));
      Modelica.Blocks.Interfaces.RealInput IntrathoracicPresssure "in torr" annotation(Placement(visible=true, transformation(origin={-84,75.9868}, extent={{-14,-14.0132},{14,14.0132}}, rotation=0), iconTransformation(origin={12,48}, extent={{-8,-8},{8,8}}, rotation=-90)));
      Haemodynamics.Parts.VariableBloodResistor pulmonaryVeinResistance annotation(Placement(transformation(extent={{54,-72},{78,-48}})));
      Haemodynamics.Parts.Constant RLAIN(k=0.003) annotation(Placement(transformation(extent={{-4,-4},{4,4}}, rotation=180, origin={88,-36})));
    equation 
      connect(PulmonaryVeins.Elastance,EPV.y) annotation(Line(points={{49.6128,0.74704},{49.6128,25.88},{71.4,25.88}}, color={0,0,127}, smooth=Smooth.Bezier));
      connect(RPP.y,PulmonaryArteriesResistance.BloodResistance) annotation(Line(points={{-31.4,-85.88},{-28,-86},{-27,-86},{-27,-72.0339}}, color={0,0,127}, smooth=Smooth.Bezier));
      connect(VPAU.y,PulmonaryArteries.UnstressedVolume) annotation(Line(points={{-89.4,34.12},{-89.4,35.06},{-81.5873,35.06},{-81.5873,4.74704}}, color={0,0,127}, smooth=Smooth.Bezier));
      connect(EPA.y,PulmonaryArteries.Elastance) annotation(Line(points={{-24.6,17.88},{-24.6,17.94},{-50.3872,17.94},{-50.3872,4.74704}}, color={0,0,127}, smooth=Smooth.Bezier));
      connect(PulmonaryArteries.ExternalPressure,IntrathoracicPresssure) annotation(Line(points={{-64.7872,9.54704},{-58,50},{-58,75.9868},{-84,75.9868}}, color={0,0,127}, smooth=Smooth.Bezier));
      connect(PulmonaryArteries.bloodFlow,bloodFlowInflow) annotation(Line(points={{-66,-40},{-66,-60},{-101,-60}}, color={0,0,255}, smooth=Smooth.None, thickness=1));
      connect(bloodFlowInflow,PulmonaryArteriesResistance.Inflow) annotation(Line(points={{-101,-60},{-60.5,-60},{-60.5,-60.13},{-40,-60.13}}, color={0,0,255}, thickness=1, smooth=Smooth.None));
      connect(PulmonaryVeins.ExternalPressure,IntrathoracicPresssure) annotation(Line(points={{35.2128,5.54704},{35.2128,75.9868},{-84,75.9868}}, color={0,0,127}, smooth=Smooth.Bezier));
      connect(pulmonaryVeinResistance.Outflow,bloodFlowOutflow) annotation(Line(points={{78,-60},{90,-60},{103,-60}}, color={255,0,0}, thickness=1, smooth=Smooth.Bezier));
      connect(PulmonaryArteriesResistance.Outflow,PulmonaryVeins.bloodFlow) annotation(Line(points={{-14,-60},{34,-60},{34,-44}}, color={255,0,0}, thickness=1, smooth=Smooth.None));
      connect(PulmonaryArteriesResistance.Outflow,pulmonaryVeinResistance.Inflow) annotation(Line(points={{-14,-60},{54,-60},{54,-59.88}}, color={255,0,0}, thickness=1, smooth=Smooth.None));
      connect(pulmonaryVeinResistance.BloodResistance,RLAIN.y) annotation(Line(points={{66,-48.8918},{67,-50.8175},{68,-42},{68,-36.08},{83.6,-36.08}}, color={0,0,0}, smooth=Smooth.Bezier));
      connect(VPVU.y,PulmonaryVeins.UnstressedVolume) annotation(Line(points={{8.6,22.12},{8.6,22.06},{18.4127,22.06},{18.4127,0.74704}}, color={0,0,127}, smooth=Smooth.Bezier));
      annotation(Diagram(graphics), Icon(graphics={Ellipse(extent={{92,46},{110,-44}}, lineColor={0,0,255}, fillColor={255,170,85}, fillPattern=FillPattern.Solid),Rectangle(extent={{-100,46},{102,-44}}, fillColor={255,170,85}, fillPattern=FillPattern.Solid, pattern=LinePattern.None, lineColor={0,0,0}),Ellipse(extent={{-110,46},{-92,-44}}, lineColor={0,0,255}, fillColor={0,0,255}, fillPattern=FillPattern.Solid),Text(extent={{-106,-56},{112,-86}}, lineColor={0,0,255}, fillColor={0,0,255}, fillPattern=FillPattern.Solid, textString="%name"),Text(extent={{110,24},{-92,34}}, lineColor={0,0,0}, lineThickness=1, textString="intrathoracic pressure")}));
    end PulmonaryCirculation;

  end Parts;

  model Hemodynamics
    Haemodynamics.Parts.RightHeart rightHeart(RightAtrium(V0=40), RightVentricle(V0=130), rightAtrialElastance(EMAX=0.15)) annotation(Placement(transformation(extent={{-42,12},{-4,50}})));
    Haemodynamics.Parts.heartIntervals heartIntervals annotation(Placement(transformation(extent={{-82.0,58.0},{-62.0,78.0}}, origin={0.0,0.0}, rotation=0), visible=true));
    Haemodynamics.Parts.Constant HeartRate(k=72) annotation(Placement(transformation(extent={{-98.0,84.0},{-90.0,92.0}}, origin={0.0,0.0}, rotation=0), visible=true));
    Haemodynamics.Parts.SystemicVeins systemicVeins(ExtrathoracicVeins(V0=1760), IntrathoracicVeins(V0=1400)) annotation(Placement(transformation(extent={{-87,-79},{-39,-39}})));
    Haemodynamics.Parts.Constant Pth(k=-4) annotation(Placement(transformation(extent={{-90.0,16.0},{-82.0,24.0}}, origin={0.0,-0.0}, rotation=0), visible=true));
    Haemodynamics.Parts.PulmonaryCirculation pulmonaryCirculation(PulmonaryArteries(V0=100), PulmonaryVeins(V0=600)) annotation(Placement(transformation(extent={{4,-10},{36,20}})));
    Haemodynamics.Parts.SystemicArteries systemicArteries(IntrathoracicArteries(V0=300), ExtrathoracicArteries(V0=500), LETHA(k=0.0007)) annotation(Placement(transformation(extent={{36,-78},{84,-40}})));
    Haemodynamics.Parts.Constant RSP(k=0.8) "resistance torr sec/ml" annotation(Placement(transformation(extent={{-28,-34},{-20,-26}})));
    Haemodynamics.Parts.SystemicPeripheralVessels systemicPeripheralVessels annotation(Placement(transformation(extent={{-26,-84},{16,-44}})));
    Haemodynamics.Parts.LeftHeart leftHeart annotation(Placement(transformation(extent={{46,10},{84,48}})));
  equation 
    connect(heartIntervals.Tas,leftHeart.Tas) annotation(Line(visible=true, points={{-61.0,72.6},{38.0,72.6},{38.0,41.16},{48.66,41.16}}, color={0,0,127}));
    connect(heartIntervals.Tav,leftHeart.Tav) annotation(Line(visible=true, points={{-61.0,69.6},{34.0,69.6},{34.0,37.36},{48.66,37.36}}, color={0,0,127}));
    connect(heartIntervals.T0,leftHeart.T0) annotation(Line(visible=true, points={{-61.0,62.4},{24.0,62.4},{24.0,29.76},{48.66,29.76}}, color={0,0,127}));
    connect(heartIntervals.Tvs,leftHeart.Tvs) annotation(Line(visible=true, points={{-61.0,65.8},{30.0,65.8},{30.0,33.56},{48.66,33.56}}, color={0,0,127}));
    connect(HeartRate.y,heartIntervals.HR) annotation(Line(visible=true, points={{-89.6,88.08},{-88.0,88.08},{-88.0,70.8},{-83.4,70.8}}, color={0,0,127}));
    connect(heartIntervals.Tas,rightHeart.Tas) annotation(Line(visible=true, points={{-61.0,72.6},{-44.0,72.6},{-44.0,43.16},{-39.34,43.16}}, color={0,0,127}));
    connect(heartIntervals.Tav,rightHeart.Tav) annotation(Line(visible=true, points={{-61.0,69.6},{-46.0,69.6},{-46.0,39.36},{-39.34,39.36}}, color={0,0,127}));
    connect(heartIntervals.Tvs,rightHeart.Tvs) annotation(Line(visible=true, points={{-61.0,65.8},{-48.0,65.8},{-48.0,35.56},{-39.34,35.56}}, color={0,0,127}));
    connect(heartIntervals.T0,rightHeart.T0) annotation(Line(visible=true, points={{-61.0,62.4},{-52.0,62.4},{-52.0,31.76},{-39.34,31.76}}, color={0,0,127}));
    connect(Pth.y,leftHeart.PTH) annotation(Line(visible=true, points={{-81.6,20.08},{-66.0,20.08},{-66.0,54.0},{14.0,54.0},{14.0,45.34},{54.74,45.34}}, color={0,0,127}));
    connect(Pth.y,systemicVeins.IntrathoracicPresssure) annotation(Line(visible=true, points={{-81.6,20.08},{-66.0,20.08},{-66.0,-20.0},{-60.12,-20.0},{-60.12,-49.4}}, color={0,0,127}));
    connect(Pth.y,systemicArteries.IntrathoracicPresssure) annotation(Line(visible=true, points={{-81.6,20.08},{-66.0,20.08},{-66.0,-20.0},{62.88,-20.0},{62.88,-49.88}}, color={0,0,127}));
    connect(Pth.y,pulmonaryCirculation.IntrathoracicPresssure) annotation(Line(visible=true, points={{-81.6,20.08},{-66.0,20.08},{-66.0,54.0},{14.0,54.0},{14.0,18.0},{21.92,18.0},{21.92,12.2}}, color={0,0,127}));
    connect(rightHeart.PTH,Pth.y) annotation(Line(visible=true, points={{-33.26,47.34},{-66.0,47.34},{-66.0,20.08},{-81.6,20.08}}, color={0,0,127}));
    connect(systemicVeins.bloodFlowOutflow,rightHeart.fromCentralVeins) annotation(Line(points={{-89.16,-60.4},{-96,-60.4},{-96,6},{-38.77,6},{-38.77,21.69}}, color={0,0,255}, smooth=Smooth.None, thickness=1));
    connect(pulmonaryCirculation.bloodFlowInflow,rightHeart.toPulmonaryArtery) annotation(Line(points={{1.92,5.15},{-5.71,5.15},{-5.71,22.83}}, color={0,0,255}, thickness=1, smooth=Smooth.None));
    connect(systemicVeins.bloodFlowInflow,systemicPeripheralVessels.bloodFlowOutflow) annotation(Line(points={{-36.84,-60.4},{-28,-60.4},{-28,-60},{-24.95,-60}}, color={0,0,255}, smooth=Smooth.None, thickness=1));
    connect(systemicArteries.bloodFlowOutflow,systemicPeripheralVessels.bloodFlowInflow) annotation(Line(points={{33.84,-60.33},{18,-60.33},{18,-60},{16,-60},{14.95,-60.2}}, color={255,0,0}, smooth=Smooth.None, thickness=1));
    connect(systemicPeripheralVessels.PeripheralArteriolarResistance,RSP.y) annotation(Line(points={{-7.1,-44.4},{-7.1,-29.92},{-19.6,-29.92}}, color={0,0,127}, smooth=Smooth.None));
    connect(pulmonaryCirculation.bloodFlowOutflow,leftHeart.fromPulmonaryVeins) annotation(Line(points={{38.72,4.55},{49.23,4.55},{49.23,19.69}}, color={255,0,0}, thickness=1, smooth=Smooth.None));
    connect(leftHeart.toAorta,systemicArteries.bloodFlowInflow) annotation(Line(points={{82.29,20.83},{96,20.83},{96,-60.33},{86.16,-60.33}}, color={255,0,0}, thickness=1, smooth=Smooth.None));
    annotation(Diagram(graphics), Icon(coordinateSystem(extent={{-100.0,-100.0},{100.0,100.0}}, preserveAspectRatio=true, initialScale=0.1, grid={10,10}), graphics={Text(visible=true, origin={0.0,-81.0193}, fillPattern=FillPattern.Solid, extent={{-100.0,-18.9807},{100.0,18.9807}}, textString="Hemodynamics", fontName="Arial"),Bitmap(visible=true, origin={0.0,15.0}, fileName="", imageSource="iVBORw0KGgoAAAANSUhEUgAAAd4AAANvCAYAAABzl7s6AAAACXBIWXMAAAsTAAALEwEAmpwY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", extent={{-100.0,-85.0},{100.0,85.0}})}), experiment(StopTime=20, NumberOfIntervals=5000));
  end Hemodynamics;

end Haemodynamics;
